==> peony_2.1.2.orig.tar.gz: peony/libpeony-qt/controls/navigation-bar/advanced-location-bar.h <==
/*
 * Peony-Qt's Library
 *
 * Copyright (C) 2019, Tianjin KYLIN Information Technology Co., Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Yue Lan <lanyue@kylinos.cn>
 *
 */

#ifndef ADVANCEDLOCATIONBAR_H
#define ADVANCEDLOCATIONBAR_H

#include <QWidget>
#include <QLineEdit>
#include "peony-core_global.h"

class QStackedLayout;

namespace Peony {

class LocationBar;
class PathEdit;

class PEONYCORESHARED_EXPORT AdvancedLocationBar : public QWidget
{
    Q_OBJECT
public:
    explicit AdvancedLocationBar(QWidget *parent = nullptr);
    bool isEditing();

Q_SIGNALS:
    void updateWindowLocationRequest(const QString &uri, bool addHistory = true, bool forceUpdate = false);
    void refreshRequest();
    void searchRequest(const QString &key);

public Q_SLOTS:
    void updateLocation(const QString &uri);
    void startEdit();
    void finishEdit();
    void switchEditMode(bool bSearchMode);

private:
    QStackedLayout *m_layout;

    LocationBar *m_bar;
    PathEdit *m_edit;
    QLineEdit *m_search_bar;

    QString m_text;
};

}

#endif // ADVANCEDLOCATIONBAR_H

==> peony_3.0.6.orig.tar.gz: peony/libpeony-qt/controls/navigation-bar/advanced-location-bar.h <==
/*
 * Peony-Qt's Library
 *
 * Copyright (C) 2020, KylinSoft Co., Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Yue Lan <lanyue@kylinos.cn>
 *
 */

#ifndef ADVANCEDLOCATIONBAR_H
#define ADVANCEDLOCATIONBAR_H

#include <QWidget>
#include "peony-core_global.h"

class QStackedLayout;

namespace Peony {

class LocationBar;
class PathEdit;
class SearchBarContainer;

class PEONYCORESHARED_EXPORT AdvancedLocationBar : public QWidget
{
    Q_OBJECT
public:
    explicit AdvancedLocationBar(QWidget *parent = nullptr);
    bool isEditing();

Q_SIGNALS:
    void updateWindowLocationRequest(const QString &uri, bool addHistory = true, bool forceUpdate = false);
    void refreshRequest();
    void searchRequest(const QString &path, const QString &key);
    void updateFileTypeFilter(const int &index);

public Q_SLOTS:
    void updateLocation(const QString &uri);
    void startEdit();
    void finishEdit();
    void switchEditMode(bool bSearchMode);
    void clearSearchBox();

private:
    QStackedLayout *m_layout;

    LocationBar *m_bar;
    PathEdit *m_edit;
    SearchBarContainer *m_search_bar;

    QString m_text;
    QString m_last_non_search_path;
    QString m_last_key = "";
};

}

#endif // ADVANCEDLOCATIONBAR_H
